@@ -3,7 +3,7 @@ tv.eco <- function (...) stop('This function is deprecated, use tv.traits instea
 tv.traits <- function (db, trait.db = 'ecodbase.dbf', refl, ...) {
     tv_home <- tv.home()
     if(missing(refl))  refl <- if(missing(db)) tv.refl() else tv.refl(db = db)
-    ecodb <- read.dbf(file.path(tv_home, 'Species', refl, trait.db))
+    ecodb <- read.dbf(file.path(tv_home, 'Species', refl, trait.db), as.is = TRUE)
     empty <- function(x) all(is.na(x) | x == 0)
     na <- apply(ecodb, 2, empty)
     if(any(na)) {
@@ -15,12 +15,12 @@ tv.traits <- function (db, trait.db = 'ecodbase.dbf', refl, ...) {
 #    if(!quiet) message("Changing character fields into logical, integer or numericals if appropriate.")
 # ecoDB <- apply(ecodb, 2, function(x) type.convert(as.character(x))) # doesnt work 
     ecoDB <- ecodb
-    for(i in 1:ncol(ecodb)) if(is.factor(ecodb[,i])) {
-      ecoDB[,i] <- iconv(as.character(ecodb[,i], "WINDOWS-1250", ""))
-      ecoDB[,i] <- type.convert(ecoDB[,i]) }
-    for(i in 1:ncol(ecoDB))  if(class(ecodb[,i]) != class(ecoDB[,i]))
-      ecoDB$ABBREVIAT <- as.character(ecoDB$ABBREVIAT)
-      ecoDB$LETTERCODE <- as.character(ecoDB$LETTERCODE)
+#     for(i in 1:ncol(ecodb)) if(is.factor(ecodb[,i])) {
+#       ecoDB[,i] <- iconv(as.character(ecodb[,i], "CP437", ""))
+#       ecoDB[,i] <- type.convert(ecoDB[,i]) }
+#     for(i in 1:ncol(ecoDB))  if(class(ecodb[,i]) != class(ecoDB[,i]))
+#       ecoDB$ABBREVIAT <- as.character(ecoDB$ABBREVIAT)
+#       ecoDB$LETTERCODE <- as.character(ecoDB$LETTERCODE)
 #       if(!quiet) message('Data type of ', names(ecoDB)[i], ' changed to ', class(ecoDB[,i]))    
     return(ecoDB)
 }
@@ -36,7 +36,7 @@ meanTraits <- function(trait, veg, refl, trait.db = 'ecodbase.dbf', join = 'LETT
     }
   eco <- tv.traits(trait.db = trait.db, refl=refl, quiet=TRUE)
   if(!trait %in% names(eco)) stop(paste('This trait name does not occur in column names of', trait.db))
-  IV <- eco[,trait][match(names(veg), eco[,join])]
+  IV <- as.numeric(eco[,trait][match(names(veg), eco[,join])])
   names(IV) <- names(veg)
   if(zero.is.NA) IV[IV == 0] <- NA
   ind <- !is.na(IV)
